utils::globalVariables(c("group",
                         "value",
                         "prop",
                         "pie_template_list",
                         "pie_template_list_pro",
                         "ymax",
                         "ymin",
                         "labelPosition",
                         "x",
                         "y",
                         "id",
                         "individual",
                         "hjust"))
